@@ -319,22 +319,26 @@ class TestModelUpload(object):
             result = runner.invoke(cli.cli, self.BASE_COMMAND)
 
             assert result.output == self.EXPECTED_STDOUT, result.exc_info
-            post_patched.assert_called_with(self.URL,
-                                            headers=EXPECTED_HEADERS,
-                                            json=None,
-                                            files=None,
-                                            data=None,
-                                            params=self.BASE_PARAMS)
+            post_patched.assert_has_calls([
+                mock.call(self.URL,
+                          headers=EXPECTED_HEADERS,
+                          json=None,
+                          files=None,
+                          data=None,
+                          params=self.BASE_PARAMS),
+            ])
+            put_patched.assert_has_calls([
+                mock.call(self.GET_PRESIGNED_URL_RESPONSE,
+                          headers={"Content-Type": mock.ANY},
+                          json=None,
+                          params=None,
+                          data=mock.ANY)
+            ])
             get_patched.assert_called_once_with(self.GET_PRESIGNED_URL,
                                                 headers=EXPECTED_HEADERS,
                                                 params=self.GET_PRESIGNED_URL_PARAMS,
                                                 json=None,
                                                 )
-            put_patched.assert_called_once_with(self.GET_PRESIGNED_URL_RESPONSE,
-                                                headers={"Content-Type": ""},
-                                                json=None,
-                                                params=None,
-                                                data=mock.ANY)
             assert put_patched.call_args.kwargs["data"].encoder.fields["file"][0] == self.MODEL_FILE
 
             assert EXPECTED_HEADERS["X-API-Key"] != "some_key"
@@ -356,22 +360,25 @@ class TestModelUpload(object):
             result = runner.invoke(cli.cli, self.COMMAND_WITH_ALL_OPTIONS)
 
             assert result.output == self.EXPECTED_STDOUT, result.exc_info
-            post_patched.assert_called_with(self.URL,
-                                            headers=EXPECTED_HEADERS,
-                                            json=None,
-                                            files=None,
-                                            data=None,
-                                            params=self.ALL_OPTIONS_PARAMS)
+            post_patched.assert_has_calls([
+                mock.call(self.URL,
+                          headers=EXPECTED_HEADERS,
+                          json=None,
+                          files=None,
+                          data=None,
+                          params=self.ALL_OPTIONS_PARAMS),
+            ])
+            put_patched.assert_has_calls([
+                mock.call(self.GET_PRESIGNED_URL_RESPONSE,
+                          headers={"Content-Type": mock.ANY},
+                          json=None,
+                          params=None,
+                          data=mock.ANY)])
             get_patched.assert_called_once_with(self.GET_PRESIGNED_URL,
                                                 headers=EXPECTED_HEADERS,
                                                 params=self.GET_PRESIGNED_URL_PARAMS,
                                                 json=None,
                                                 )
-            put_patched.assert_called_once_with(self.GET_PRESIGNED_URL_RESPONSE,
-                                                headers={"Content-Type": ""},
-                                                json=None,
-                                                params=None,
-                                                data=mock.ANY)
             assert put_patched.call_args.kwargs["data"].encoder.fields["file"][0] == self.MODEL_FILE
 
             assert EXPECTED_HEADERS["X-API-Key"] != "some_key"
@@ -393,22 +400,27 @@ class TestModelUpload(object):
             result = runner.invoke(cli.cli, self.COMMAND_WITH_API_KEY_PARAMETER_USED)
 
             assert result.output == self.EXPECTED_STDOUT, result.exc_info
-            post_patched.assert_called_with(self.URL,
-                                            headers=EXPECTED_HEADERS_WITH_CHANGED_API_KEY,
-                                            json=None,
-                                            files=None,
-                                            data=None,
-                                            params=self.ALL_OPTIONS_PARAMS)
+            post_patched.assert_has_calls([
+                mock.call(self.URL,
+                          headers=EXPECTED_HEADERS_WITH_CHANGED_API_KEY,
+                          json=None,
+                          files=None,
+                          data=None,
+                          params=self.ALL_OPTIONS_PARAMS
+                          ),
+            ])
+            put_patched.assert_has_calls([
+                mock.call(self.GET_PRESIGNED_URL_RESPONSE,
+                          headers={"Content-Type": mock.ANY},
+                          json=None,
+                          params=None,
+                          data=mock.ANY)
+            ])
             get_patched.assert_called_once_with(self.GET_PRESIGNED_URL,
                                                 headers=EXPECTED_HEADERS_WITH_CHANGED_API_KEY,
                                                 params=self.GET_PRESIGNED_URL_PARAMS,
                                                 json=None,
                                                 )
-            put_patched.assert_called_once_with(self.GET_PRESIGNED_URL_RESPONSE,
-                                                headers={"Content-Type": ""},
-                                                json=None,
-                                                params=None,
-                                                data=mock.ANY)
             assert put_patched.call_args.kwargs["data"].encoder.fields["file"][0] == self.MODEL_FILE
 
             assert EXPECTED_HEADERS["X-API-Key"] != "some_key"
@@ -431,22 +443,26 @@ class TestModelUpload(object):
             result = runner.invoke(cli.cli, command)
 
             assert result.output == self.EXPECTED_STDOUT, result.exc_info
-            post_patched.assert_called_with(self.URL,
-                                            headers=EXPECTED_HEADERS_WITH_CHANGED_API_KEY,
-                                            json=None,
-                                            files=None,
-                                            data=None,
-                                            params=self.ALL_OPTIONS_PARAMS)
-            get_patched.assert_called_once_with(self.GET_PRESIGNED_URL,
-                                                headers=EXPECTED_HEADERS_WITH_CHANGED_API_KEY,
-                                                params=self.GET_PRESIGNED_URL_PARAMS,
-                                                json=None,
-                                                )
+            post_patched.assert_has_calls([
+                mock.call(
+                    self.URL,
+                    headers=EXPECTED_HEADERS_WITH_CHANGED_API_KEY,
+                    json=None,
+                    files=None,
+                    data=None,
+                    params=self.ALL_OPTIONS_PARAMS
+                ),
+            ])
             put_patched.assert_called_once_with(self.GET_PRESIGNED_URL_RESPONSE,
                                                 headers={"Content-Type": ""},
                                                 json=None,
                                                 params=None,
                                                 data=mock.ANY)
+            get_patched.assert_called_once_with(self.GET_PRESIGNED_URL,
+                                                headers=EXPECTED_HEADERS_WITH_CHANGED_API_KEY,
+                                                params=self.GET_PRESIGNED_URL_PARAMS,
+                                                json=None,
+                                                )
             assert put_patched.call_args.kwargs["data"].encoder.fields["file"][0] == self.MODEL_FILE
 
             assert EXPECTED_HEADERS["X-API-Key"] != "some_key"
@@ -488,16 +504,17 @@ class TestModelUpload(object):
                 h.write("I'm a model!")
 
             result = runner.invoke(cli.cli, self.BASE_COMMAND_WITH_TAGS)
-
             assert result.output == self.EXPECTED_STDOUT, result.exc_info
-            post_patched.assert_called_with(
-                self.URL,
-                headers=EXPECTED_HEADERS,
-                json=None,
-                files=None,
-                data=None,
-                params=self.BASE_PARAMS,
-            )
+            post_patched.assert_has_calls([
+                mock.call(self.URL,
+                          headers=EXPECTED_HEADERS,
+                          json=None,
+                          files=None,
+                          data=None,
+                          params=self.BASE_PARAMS
+                          ),
+            ])
+
             get_patched.assert_has_calls(
                 [
                     mock.call(
@@ -512,7 +529,7 @@ class TestModelUpload(object):
                 [
                     mock.call(
                         self.GET_PRESIGNED_URL_RESPONSE,
-                        headers={"Content-Type": ""},
+                        headers={"Content-Type": mock.ANY},
                         json=None,
                         params=None,
                         data=mock.ANY,
